@@ -1,13 +1,15 @@
-use crate::{
-    consensus::{SwitchForkDecision, Tower},
-    latest_validator_votes_for_frozen_banks::LatestValidatorVotesForFrozenBanks,
-    progress_map::ProgressMap,
-    replay_stage::HeaviestForkFailures,
-};
-use solana_runtime::{bank::Bank, bank_forks::BankForks};
-use std::{
-    collections::{HashMap, HashSet},
-    sync::{Arc, RwLock},
+use {
+    crate::{
+        consensus::{SwitchForkDecision, Tower},
+        latest_validator_votes_for_frozen_banks::LatestValidatorVotesForFrozenBanks,
+        progress_map::ProgressMap,
+        replay_stage::HeaviestForkFailures,
+    },
+    solana_runtime::{bank::Bank, bank_forks::BankForks},
+    std::{
+        collections::{HashMap, HashSet},
+        sync::{Arc, RwLock},
+    },
 };
 
 pub(crate) struct SelectVoteAndResetForkResult {
