@@ -5,7 +5,7 @@ use {
         leader_schedule_cache::LeaderScheduleCache, shred::Shred,
         sigverify_shreds::verify_shreds_gpu,
     },
-    solana_perf::{self, packet::Packets, recycler_cache::RecyclerCache},
+    solana_perf::{self, packet::PacketBatch, recycler_cache::RecyclerCache},
     solana_runtime::bank_forks::BankForks,
     std::{
         collections::{HashMap, HashSet},
@@ -32,7 +32,7 @@ impl ShredSigVerifier {
             recycler_cache: RecyclerCache::warmed(),
         }
     }
-    fn read_slots(batches: &[Packets]) -> HashSet<u64> {
+    fn read_slots(batches: &[PacketBatch]) -> HashSet<u64> {
         batches
             .iter()
             .flat_map(|batch| batch.packets.iter().filter_map(Shred::get_slot_from_packet))
@@ -41,7 +41,7 @@ impl ShredSigVerifier {
 }
 
 impl SigVerifier for ShredSigVerifier {
-    fn verify_batch(&self, mut batches: Vec<Packets>) -> Vec<Packets> {
+    fn verify_batches(&self, mut batches: Vec<PacketBatch>) -> Vec<PacketBatch> {
         let r_bank = self.bank_forks.read().unwrap().working_bank();
         let slots: HashSet<u64> = Self::read_slots(&batches);
         let mut leader_slots: HashMap<u64, [u8; 32]> = slots
@@ -88,13 +88,13 @@ pub mod tests {
             0,
             0xc0de,
         );
-        let mut batch = [Packets::default(), Packets::default()];
+        let mut batches = [PacketBatch::default(), PacketBatch::default()];
 
         let keypair = Keypair::new();
         Shredder::sign_shred(&keypair, &mut shred);
-        batch[0].packets.resize(1, Packet::default());
-        batch[0].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
-        batch[0].packets[0].meta.size = shred.payload.len();
+        batches[0].packets.resize(1, Packet::default());
+        batches[0].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
+        batches[0].packets[0].meta.size = shred.payload.len();
 
         let mut shred = Shred::new_from_data(
             0xc0de_dead,
@@ -108,16 +108,16 @@ pub mod tests {
             0xc0de,
         );
         Shredder::sign_shred(&keypair, &mut shred);
-        batch[1].packets.resize(1, Packet::default());
-        batch[1].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
-        batch[1].packets[0].meta.size = shred.payload.len();
+        batches[1].packets.resize(1, Packet::default());
+        batches[1].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
+        batches[1].packets[0].meta.size = shred.payload.len();
 
         let expected: HashSet<u64> = [0xc0de_dead, 0xdead_c0de].iter().cloned().collect();
-        assert_eq!(ShredSigVerifier::read_slots(&batch), expected);
+        assert_eq!(ShredSigVerifier::read_slots(&batches), expected);
     }
 
     #[test]
-    fn test_sigverify_shreds_verify_batch() {
+    fn test_sigverify_shreds_verify_batches() {
         let leader_keypair = Arc::new(Keypair::new());
         let leader_pubkey = leader_keypair.pubkey();
         let bank =
@@ -126,8 +126,8 @@ pub mod tests {
         let bf = Arc::new(RwLock::new(BankForks::new(bank)));
         let verifier = ShredSigVerifier::new(bf, cache);
 
-        let mut batch = vec![Packets::default()];
-        batch[0].packets.resize(2, Packet::default());
+        let mut batches = vec![PacketBatch::default()];
+        batches[0].packets.resize(2, Packet::default());
 
         let mut shred = Shred::new_from_data(
             0,
@@ -141,8 +141,8 @@ pub mod tests {
             0xc0de,
         );
         Shredder::sign_shred(&leader_keypair, &mut shred);
-        batch[0].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
-        batch[0].packets[0].meta.size = shred.payload.len();
+        batches[0].packets[0].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
+        batches[0].packets[0].meta.size = shred.payload.len();
 
         let mut shred = Shred::new_from_data(
             0,
@@ -157,10 +157,10 @@ pub mod tests {
         );
         let wrong_keypair = Keypair::new();
         Shredder::sign_shred(&wrong_keypair, &mut shred);
-        batch[0].packets[1].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
-        batch[0].packets[1].meta.size = shred.payload.len();
+        batches[0].packets[1].data[0..shred.payload.len()].copy_from_slice(&shred.payload);
+        batches[0].packets[1].meta.size = shred.payload.len();
 
-        let rv = verifier.verify_batch(batch);
+        let rv = verifier.verify_batches(batches);
         assert!(!rv[0].packets[0].meta.discard);
         assert!(rv[0].packets[1].meta.discard);
     }
